import React, { Dispatch } from "react";
import { Page } from "@/pages/base";
import { Button, Container, Typography } from "@material-ui/core";
import { Action, useDispatch } from "@/state/actions";
import { useHistory } from "react-router-dom";
import { route } from "@/routing";
import { useVerticalSpacing } from "@/styles";
import { AppState } from "@/state/reducer";

import api from "@/api";
import { UserActions } from "@/state/actions/user";
import { sampleStudent } from "@/provider/dummy";

const authorizeUser = async (dispatch: Dispatch<Action>, getState: () => AppState): Promise<void> => {
    const token = await api.user.authorize("test");

    dispatch({
        type: UserActions.Login,
        token,
        student: sampleStudent,
    })
}

export const UserLoginPage = () => {
    const dispatch = useDispatch();
    const history  = useHistory();

    const handleSampleLogin = async () => {
        await dispatch(authorizeUser);

        history.push(route("home"));
    }

    const classes = useVerticalSpacing(3);

    return <Page>
        <Page.Header maxWidth="md">
            <Page.Title>Tu miało być przekierowanie do logowania PG...</Page.Title>
        </Page.Header>
        <Container maxWidth="md" className={ classes.root }>
            <Typography variant="h3">... ale wciąż czekamy na dostęp :(</Typography>

            <Button fullWidth onClick={ handleSampleLogin } variant="contained" color="primary">Zaloguj jako przykładowy student</Button>
        </Container>
    </Page>;
}
